:math:`x(t) \longleftrightarrow X(f)`

:math:`x(a t) \longleftrightarrow \frac{X(\frac{f}{a})}{\left|{a}\right|}`

:math:`x(t - \tau) \longleftrightarrow X(f) e^{2 \mathrm{j} \pi f \tau}`

:math:`\cos{\left(2 \pi f_{0} t \right)} \longleftrightarrow \frac{\delta\left(f - f_{0}\right)}{2} + \frac{\delta\left(f + f_{0}\right)}{2}`

:math:`\sin{\left(2 \pi f_{0} t \right)} \longleftrightarrow \frac{\mathrm{j} \left(- \delta\left(f - f_{0}\right) + \delta\left(f + f_{0}\right)\right)}{2}`

:math:`e^{2 \mathrm{j} \pi f_{0} t} \longleftrightarrow \delta\left(f - f_{0}\right)`

:math:`1 \longleftrightarrow \delta\left(f\right)`

:math:`t \longleftrightarrow \frac{\mathrm{j} \delta^{\left( 1 \right)}\left( f \right)}{2 \pi}`

:math:`t^{2} \longleftrightarrow - \frac{\delta^{\left( 2 \right)}\left( f \right)}{4 \pi^{2}}`

:math:`\frac{1}{t} \longleftrightarrow - \mathrm{j} \pi \operatorname{sign}{\left(f \right)}`

:math:`\delta\left(t\right) \longleftrightarrow 1`

:math:`\delta\left(t - t_{0}\right) \longleftrightarrow e^{2 \mathrm{j} \pi f t_{0}}`

:math:`u\left(t\right) \longleftrightarrow \frac{\delta\left(f\right)}{2} - \frac{\mathrm{j}}{2 \pi f}`

:math:`t u\left(t\right) \longleftrightarrow \frac{\mathrm{j} \delta^{\left( 1 \right)}\left( f \right)}{4 \pi} - \frac{1}{4 \pi^{2} f^{2}}`

:math:`\mathrm{sign}{\left(t \right)} \longleftrightarrow - \frac{\mathrm{j}}{\pi f}`

:math:`\mathrm{rect}{\left(t \right)} \longleftrightarrow \mathrm{sincn}{\left(f \right)}`

:math:`\mathrm{sincn}{\left(t \right)} \longleftrightarrow \mathrm{rect}{\left(f \right)}`

:math:`\mathrm{tri}{\left(t \right)} \longleftrightarrow \mathrm{sincn}^{2}{\left(f \right)}`

:math:`\mathrm{trap}{\left(t,\alpha \right)} \longleftrightarrow \alpha \operatorname{sincn}{\left(f \right)} \operatorname{sincn}{\left(\alpha f \right)}`

:math:`e^{- \left|{t}\right|} \longleftrightarrow \frac{2}{4 \pi^{2} f^{2} + 1}`

:math:`e^{- t} u\left(t\right) \longleftrightarrow \frac{1}{2 \mathrm{j} \pi f + 1}`

